summaryrefslogtreecommitdiff
path: root/deps/icu-small/source/common/rbbisetb.h
diff options
context:
space:
mode:
Diffstat (limited to 'deps/icu-small/source/common/rbbisetb.h')
-rw-r--r--deps/icu-small/source/common/rbbisetb.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/deps/icu-small/source/common/rbbisetb.h b/deps/icu-small/source/common/rbbisetb.h
index a7a91b3b37..ed6a76b121 100644
--- a/deps/icu-small/source/common/rbbisetb.h
+++ b/deps/icu-small/source/common/rbbisetb.h
@@ -94,10 +94,12 @@ public:
UChar32 getFirstChar(int32_t val) const;
UBool sawBOF() const; // Indicate whether any references to the {bof} pseudo
// character were encountered.
/** merge two character categories that have been identified as having equivalent behavior.
* The ranges belonging to the right category (table column) will be added to the left.
*/
- void mergeCategories(int32_t left, int32_t right);
+ void mergeCategories(IntPair categories);
static constexpr int32_t DICT_BIT = 0x4000;
@@ -94,10 +94,12 @@ public:
UBool sawBOF() const; // Indicate whether any references to the {bof} pseudo
// character were encountered.
- /** merge two character categories that have been identified as having equivalent behavior.
- * The ranges belonging to the right category (table column) will be added to the left.
+ /**
+ * Merge two character categories that have been identified as having equivalent behavior.
+ * The ranges belonging to the second category (table column) will be added to the first.
+ * @param categories the pair of categories to be merged.
*/